<?php

/*
 * This is an improved version of the page_menu() function
 * It allows to specify at which level in the hierarchy
 * the displayed page tree is rooted and how many levels
 * are being displayed.
 * To just display the standard menu, use
 * <?php menu() ?> within your template's html code.
Sitemap --> menu(1,0, -1, false, '[a][menu_title][/a]<br />');
 * Usual calls would be (inside php code!)
 * menu(1,0,-1,false) - displays the complete page tree
 * menu(1,1,1) - show only first sub level
 * menu(1,1,-1) - 	show an expanding/collapsing menu tree starting at level 1
 *
 * Arguments:
 * 1. $menu_number:	With activitated "multiple menu" feature
 *                  you can choose which menu will be displayed
 *                  default: 1
 * 2. $start_level: The depth level of the root of the displayed
 *					menu tree. Defaults to '0', which is the top level.
 *                  '1' will show all pages starting from the first sub level.
 * 3. $recurse:     Gives the maximum number of levels to be displayed. Default
 *                  is '-1' which means 'all'.
 * 4. $collapse:    Specifies, whether the menu tree shall be
 *					expandable/collapsible (if set to 'true')
 *					or complete (all pages being displayed) if set to 'false'
 * 5. $item_template: Gives the possibility to specify the html code that is
 *                  displayed before displaying sub-pages
 * 6. $item_footer: The html code to appear after sub-pages were displayed.
 * 7. $menu_header: The html code to appear before the entire menu code and each
 *					sub tree.
 * 8. $menu_footer: The html code to appear after the entire menu code and each
 *					sub tree.
 * 9. $default_class: The (CSS) class of every menu item except the currently viewed page
 * 10. $current_calss: The class of the currently viewed page
 * 11. $parent:    (used internally) The page_id of the menu's root node, defaults is '0' (root level)
 *
 * @author      Alexander Hu
 *
 */


function menu($menu_number = 1, $start_level=0, $recurse = -1, $collapse = true, $item_template = '[a][menu_title][/a]', $item_footer = '', $menu_header = '', $menu_footer = '', $default_class = ' class="menu_default"', $current_class = ' class="menu_current"', $parent = 0) {
   global $database, $admin, $page_id, $page_trail, $default_link, $extra_sql, $extra_where_sql;
   if ($recurse==0)
       return;
   if ($start_level>0) {
       $key_array=array_keys($page_trail);
       $real_start=$key_array[$start_level-1];
       if (isset($real_start))
       {
          menu($menu_number, 0, $recurse,$collapse,$item_template, $item_footer, $menu_header, $menu_footer, $default_class, $current_class, $real_start);
      }
       return;
   }
   // Check if we should add menu number check to query
   if($parent == 0) {
       $menu_number = "menu = '$menu_number'";
   } else {
      $menu_number = '1';
   }
   // Query pages
   $query_menu = $database->query("SELECT page_id,menu_title,page_title,link,target,level,visibility$extra_sql FROM ".
TABLE_PREFIX."pages WHERE parent = '$parent' AND $menu_number AND $extra_where_sql ORDER BY position ASC");
   // Check if there are any pages to show
   if($query_menu->numRows() > 0) {
      // Print menu header
      echo "\n".$menu_header;
      // Loop through pages
      while($page = $query_menu->fetchRow()) {
         // Check if this page should be shown
         // Create vars
         $vars = array('[class]','[a]', '[/a]', '[menu_title]', '[page_title]');
         // Work-out class
         if($page['page_id'] == PAGE_ID) {
            $class = $current_class;
         } else {
            $class = $default_class;
         }
         // Check if link is same as first page link, and if so change to WB URL
         if($page['link'] == $default_link AND !INTRO_PAGE) {
            $link = WB_URL;
         } else {
            $link = page_link($page['link']);
         }
         // Create values
         $values = array($class,'<a href="'.$link.'" target="'.$page['target'].'" '.$class.'>', '</a>', stripslashes($page['menu_title']), stripslashes($page['page_title']));
         // Replace vars with value and print
         echo "\n".str_replace($vars, $values, $item_template);
         // Generate sub-menu
         if($collapse==false OR ($collapse==true AND isset($page_trail[$page['page_id']]))) {
            menu($menu_number, 0, $recurse-1, $collapse, '> '.$item_template, $item_footer, $menu_header, $menu_footer, $default_class, $current_class, $page['page_id']);
         }
         echo "\n".$item_footer;
      }
      // Print menu footer
      echo "\n".$menu_footer;
   }
}

?>
